import Helper from "../utils/helper";
class Submission {
    id;
    lang;
    memory;
    runtime;
    statusDisplay;
    timestamp;
    code;
    sourceUrl;
    constructor(id, lang, memory, runtime, statusDisplay, timestamp, code, sourceUrl) {
        this.id = id;
        this.lang = lang;
        this.memory = memory;
        this.runtime = runtime;
        this.statusDisplay = statusDisplay;
        this.timestamp = timestamp;
        this.code = code;
        this.sourceUrl = sourceUrl;
    }
    static async build(id) {
        const submission = new Submission(id);
        await submission.detail();
        return submission;
    }
    async detail() {
        const response = await Helper.GraphQLRequest({
            query: `
                query mySubmissionDetail($id: ID!) {
                    submissionDetail(submissionId: $id) {
                    id
                    code
                    runtime
                    memory
                    rawMemory
                    statusDisplay
                    timestamp
                    lang
                    passedTestCaseCnt
                    totalTestCaseCnt
                    sourceUrl
                    question {
                        titleSlug
                        title
                        translatedTitle
                        questionId
                        __typename
                    }
                    ... on GeneralSubmissionNode {
                        outputDetail {
                        codeOutput
                        expectedOutput
                        input
                        compileError
                        runtimeError
                        lastTestcase
                        __typename
                        }
                        __typename
                    }
                    submissionComment {
                        comment
                        flagType
                        __typename
                    }
                    __typename
                    }
                }
            `,
            variables: {
                id: this.id.toString(),
            },
        });
        const submissionDetail = response.submissionDetail;
        this.lang = submissionDetail.lang;
        this.memory = submissionDetail.memory;
        this.runtime = submissionDetail.runtime;
        this.statusDisplay = submissionDetail.statusDisplay;
        this.timestamp = submissionDetail.timestamp;
        this.code = submissionDetail.code;
        this.sourceUrl = submissionDetail.sourceUrl;
        return this;
    }
    getSubmissionUrl() {
        return Helper.uris.submission.replace("$id", this.id.toString());
    }
}
export default Submission;
//# sourceMappingURL=submission.js.map